@@ -283,7 +283,7 @@ def diff():
         for doc in workTree:
             if doc.split('/')[-1] in os.listdir(sourceDir + '/' + '/'.join(doc.split('/')[1:-1])):
                 stats.append(FileStats(doc))
-                PrLightPurple(doc)
+                print(' ' + doc)
             else:
                 PrYellow(doc + ' will be deleted in target languages.')
         fls = list(filter(lambda x: x is not None, stats))
